==> mobile_pos-0.8.12.tar.gz: lib/mobile_pos_platform_interface.dart <==
import 'dart:async';

import 'package:flutter/material.dart';
import 'package:mobile_pos/mobile_pos_sdk.dart';
import 'package:mobile_pos/src/models/bluetooth_model.dart';
import 'package:plugin_platform_interface/plugin_platform_interface.dart';

import 'mobile_pos_method_channel.dart';

abstract class MobilePosPlatform extends PlatformInterface {
  /// Constructs a MobilePosPlatform.
  MobilePosPlatform() : super(token: _token);

  static final Object _token = Object();

  static MobilePosPlatform _instance = MethodChannelMobilePos();

  /// The default instance of [MobilePosPlatform] to use.
  ///
  /// Defaults to [MethodChannelMobilePos].
  static MobilePosPlatform get instance => _instance;

  /// Platform-specific implementations should set this with their own
  /// platform-specific class that extends [MobilePosPlatform] when
  /// they register themselves.
  static set instance(MobilePosPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  BankBoxConfig? config;

  StreamController<dynamic>? channelStreamController;

  void initMethodChannel() {
    throw UnimplementedError('platformVersion() has not been implemented.');
  }

  Future<String?> getPlatformVersion() {
    throw UnimplementedError('platformVersion() has not been implemented.');
  }

  Future<String?> chargeCard(
    BuildContext context, {
    required double amount,
    required String accountType,
    required ConnectivityType connectivityType,
    String? pin,
  }) {
    throw UnimplementedError('Not implemented.');
  }

  Future<void> startRavenPay(BuildContext context) {
    throw UnimplementedError('Not implemented.');
  }

  Future<void> closeRavenPay(BuildContext context) {
    throw UnimplementedError('Not implemented.');
  }

  void setConfig(BankBoxConfig config) {
    throw UnimplementedError('Not implemented.');
  }

  Future<void> connectBluetooth(BluetoothModel model) {
    throw UnimplementedError('Not implemented.');
  }

  Future<void> onPinRequest(String pin) {
    throw UnimplementedError('Not implemented.');
  }

  Future<void> scanForMPosDevice() {
    throw UnimplementedError('Not implemented.');
  }

  Future<void> disconnectBluetoothDevice() {
    throw UnimplementedError('Not implemented.');
  }

  @Deprecated(
      "Use disconnectBluetoothDevice().... disconnectDevice() will be removed in feature release")
  Future<void> disconnectDevice() {
    throw UnimplementedError('Not implemented.');
  }

  Future<void> cancelOnPinEntry() {
    throw UnimplementedError('Not implemented.');
  }

  Future<dynamic> initLocationStatus() async {
    throw UnimplementedError('Not implemented.');
  }
}

==> mobile_pos-1.1.1.tar.gz: lib/mobile_pos_platform_interface.dart <==
import 'dart:async';

import 'package:flutter/material.dart';
import 'package:mobile_pos/mobile_pos_sdk.dart';
import 'package:mobile_pos/src/models/bluetooth_model.dart';
import 'package:plugin_platform_interface/plugin_platform_interface.dart';

import 'mobile_pos_method_channel.dart';

abstract class MobilePosPlatform extends PlatformInterface {
  /// Constructs a MobilePosPlatform.
  MobilePosPlatform() : super(token: _token);

  static final Object _token = Object();

  static MobilePosPlatform _instance = MethodChannelMobilePos();

  /// The default instance of [MobilePosPlatform] to use.
  ///
  /// Defaults to [MethodChannelMobilePos].
  static MobilePosPlatform get instance => _instance;

  /// Platform-specific implementations should set this with their own
  /// platform-specific class that extends [MobilePosPlatform] when
  /// they register themselves.
  static set instance(MobilePosPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  BankBoxConfig? config;

  StreamController<dynamic>? channelStreamController;

  void initMethodChannel() {
    throw UnimplementedError('platformVersion() has not been implemented.');
  }

  Future<String?> getPlatformVersion() {
    throw UnimplementedError('platformVersion() has not been implemented.');
  }

  Future<String?> chargeCard(
    BuildContext context, {
    required double amount,
    required String accountType,
    required ConnectivityType connectivityType,
    String? pin,
  }) {
    throw UnimplementedError('Not implemented.');
  }

  Future<void> startRavenPay(BuildContext context, {double? amount}) {
    throw UnimplementedError('Not implemented.');
  }

  Future<void> closeRavenPay(BuildContext context) {
    throw UnimplementedError('Not implemented.');
  }

  void setConfig(BankBoxConfig config) {
    throw UnimplementedError('Not implemented.');
  }

  Future<void> connectBluetooth(BluetoothModel model) {
    throw UnimplementedError('Not implemented.');
  }

  Future<void> onPinRequest(String pin) {
    throw UnimplementedError('Not implemented.');
  }

  Future<void> scanForMPosDevice() {
    throw UnimplementedError('Not implemented.');
  }

  Future<void> disconnectBluetoothDevice() {
    throw UnimplementedError('Not implemented.');
  }

  @Deprecated(
      "Use disconnectBluetoothDevice().... disconnectDevice() will be removed in feature release")
  Future<void> disconnectDevice() {
    throw UnimplementedError('Not implemented.');
  }

  Future<void> cancelOnPinEntry() {
    throw UnimplementedError('Not implemented.');
  }

  Future<dynamic> initLocationStatus() async {
    throw UnimplementedError('Not implemented.');
  }
}
